@@ -166,6 +166,7 @@ def wheel_files_pyside_essentials() -> List[ModuleData]:
         module_QtQml(),
         module_QtQuick(),
         module_QtQuickControls2(),
+        module_QtQuickTest(),
         module_QtQuickWidgets(),
         module_QtXml(),
         module_QtTest(),
@@ -458,6 +459,7 @@ def module_QtQml() -> ModuleData:
         "libQt6QmlCore",
         "libQt6QmlLocalStorage",
         "libQt6QmlModels",
+        "libQt6QmlNetwork",
         "libQt6QmlWorkerScript",
         "libQt6QmlXmlListModel",
         "libQt6QmlCompiler"
@@ -559,6 +561,7 @@ def module_QtQuick() -> ModuleData:
         "libQt6QuickTemplates2",
         "libQt6QuickTest",
         "libQt6QuickTimeline",
+        "libQt6QuickTimelineBlendTrees",
     ]
 
     # Adding GraphicalEffects files
@@ -574,12 +577,35 @@ def module_QtQuick() -> ModuleData:
 
 def module_QtQuickControls2() -> ModuleData:
     data = ModuleData("QuickControls2")
+    data.qtlib.append("libQt6QuickControls2")
+    data.qtlib.append("libQt6QuickControls2Basic")
+    data.qtlib.append("libQt6QuickControls2BasicStyleImpl")
+    data.qtlib.append("libQt6QuickControls2Fusion")
+    data.qtlib.append("libQt6QuickControls2FusionStyleImpl")
+    data.qtlib.append("libQt6QuickControls2Imagine")
+    data.qtlib.append("libQt6QuickControls2ImagineStyleImpl")
     data.qtlib.append("libQt6QuickControls2Impl")
+    data.qtlib.append("libQt6QuickControls2Material")
+    data.qtlib.append("libQt6QuickControls2MaterialStyleImpl")
+    data.qtlib.append("libQt6QuickControls2Universal")
+    data.qtlib.append("libQt6QuickControls2UniversalStyleImpl")
+    if sys.platform == "win32":
+        data.qtlib.append("libQt6QuickControls2WindowsStyleImpl")
+    elif sys.platform == "darwin":
+        data.qtlib.append("libQt6QuickControls2IOSStyleImpl")
+        data.qtlib.append("libQt6QuickControls2MacOSStyleImpl")
+
     data.metatypes.append("qt6quickcontrols2impl_relwithdebinfo_metatypes.json")
 
     return data
 
 
+def module_QtQuickTest() -> ModuleData:
+    data = ModuleData("QuickTest")
+
+    return data
+
+
 def module_QtQuickWidgets() -> ModuleData:
     data = ModuleData("QuickWidgets")
     return data
@@ -704,10 +730,14 @@ def module_QtQuick3D() -> ModuleData:
         "libQt6Quick3DEffects",
         "libQt6Quick3DGlslParser",
         "libQt6Quick3DHelpers",
+        "libQt6Quick3DHelpersImpl",
         "libQt6Quick3DIblBaker",
         "libQt6Quick3DParticleEffects",
         "libQt6Quick3DParticles",
+        "libQt6Quick3DPhysics",
+        "libQt6Quick3DPhysicsHelpers",
         "libQt6Quick3DRuntimeRender",
+        "libQt6Quick3DSpatialAudio",
         "libQt6Quick3DUtils",
         "libQt6ShaderTools",
         "libQt63DQuick",
@@ -818,6 +848,10 @@ def module_QtMultimedia() -> ModuleData:
     data.translations.append("qtmultimedia_*")
     data.plugins = get_module_plugins(json_data)
 
+    if sys.platform == "win32":
+        data.extra_files.extend(["avcodec-60.dll", "avformat-60.dll", "avutil-58.dll",
+                                 "swresample-4.dll", "swscale-7.dll"])
+
     return data
 
 
